:root {
  font-family: "Inter", system-ui, -apple-system, BlinkMacSystemFont, "Segoe UI",
    sans-serif;
  color-scheme: light dark;
  color: rgba(255, 255, 255, 0.87);
  background-color: #0f172a;
}

body {
  margin: 0;
  display: flex;
  min-height: 100vh;
}

.app {
  margin: auto;
  max-width: 640px;
  padding: 3rem;
  background: rgba(15, 23, 42, 0.8);
  border-radius: 24px;
  box-shadow: 0 30px 60px rgba(15, 23, 42, 0.4);
}

.app h1 {
  margin-top: 0;
  margin-bottom: 1rem;
  font-size: 2.5rem;
}

.app p {
  margin: 0;
  line-height: 1.7;
}
